pub struct SeqFile { /* private fields */ }Expand description
A utility for generating the contents of a seq file.
Implementations
Sourceimpl SeqFile
impl SeqFile
Sourcepub unsafe fn from_raw<'a>(ptr: *mut seq_file) -> &'a SeqFile
pub unsafe fn from_raw<'a>(ptr: *mut seq_file) -> &'a SeqFile
Creates a new SeqFile from a raw pointer.
Safety
The caller must ensure that for the duration of 'a the following is satisfied:
-
The pointer points at a valid
struct seq_file. -
The
struct seq_fileis not accessed from any other thread. -
the pointer
ptrmust point to a value ofbindings :: seq_file -
The argument
SeqFilecan only be called or accessed on the current thread.
Sourcepub fn call_printf(&self, args: Arguments<'_>)
pub fn call_printf(&self, args: Arguments<'_>)
Used by the seq_print macro.